==> StanHeaders_2.10.0.tar.gz: StanHeaders/inst/include/stan/math/fwd/mat.hpp <==
#ifndef STAN_MATH_FWD_MAT_HPP
#define STAN_MATH_FWD_MAT_HPP

#include <stan/math/fwd/core.hpp>
#include <stan/math/fwd/scal/meta/is_fvar.hpp>
#include <stan/math/fwd/scal/meta/partials_type.hpp>

#include <stan/math/prim/mat.hpp>
#include <stan/math/fwd/arr.hpp>

#include <stan/math/fwd/mat/fun/Eigen_NumTraits.hpp>
#include <stan/math/fwd/mat/fun/columns_dot_product.hpp>
#include <stan/math/fwd/mat/fun/columns_dot_self.hpp>
#include <stan/math/fwd/mat/fun/crossprod.hpp>
#include <stan/math/fwd/mat/fun/determinant.hpp>
#include <stan/math/fwd/mat/fun/divide.hpp>
#include <stan/math/fwd/mat/fun/dot_product.hpp>
#include <stan/math/fwd/mat/fun/dot_self.hpp>
#include <stan/math/fwd/mat/fun/inverse.hpp>
#include <stan/math/fwd/mat/fun/log_determinant.hpp>
#include <stan/math/fwd/mat/fun/log_softmax.hpp>
#include <stan/math/fwd/mat/fun/log_sum_exp.hpp>
#include <stan/math/fwd/mat/fun/mdivide_left.hpp>
#include <stan/math/fwd/mat/fun/mdivide_left_ldlt.hpp>
#include <stan/math/fwd/mat/fun/mdivide_left_tri_low.hpp>
#include <stan/math/fwd/mat/fun/mdivide_right.hpp>
#include <stan/math/fwd/mat/fun/mdivide_right_tri_low.hpp>
#include <stan/math/fwd/mat/fun/multiply.hpp>
#include <stan/math/fwd/mat/fun/multiply_lower_tri_self_transpose.hpp>
#include <stan/math/fwd/mat/fun/qr_Q.hpp>
#include <stan/math/fwd/mat/fun/qr_R.hpp>
#include <stan/math/fwd/mat/fun/quad_form_sym.hpp>
#include <stan/math/fwd/mat/fun/rows_dot_product.hpp>
#include <stan/math/fwd/mat/fun/rows_dot_self.hpp>
#include <stan/math/fwd/mat/fun/softmax.hpp>
#include <stan/math/fwd/mat/fun/sort_asc.hpp>
#include <stan/math/fwd/mat/fun/sort_desc.hpp>
#include <stan/math/fwd/mat/fun/sum.hpp>
#include <stan/math/fwd/mat/fun/tcrossprod.hpp>
#include <stan/math/fwd/mat/fun/to_fvar.hpp>
#include <stan/math/fwd/mat/fun/trace_gen_quad_form.hpp>
#include <stan/math/fwd/mat/fun/trace_quad_form.hpp>
#include <stan/math/fwd/mat/fun/typedefs.hpp>
#include <stan/math/fwd/mat/fun/unit_vector_constrain.hpp>

#include <stan/math/fwd/mat/functor/gradient.hpp>
#include <stan/math/fwd/mat/functor/jacobian.hpp>

#endif

==> StanHeaders_2.11.0.tar.gz: StanHeaders/inst/include/stan/math/fwd/mat.hpp <==
#ifndef STAN_MATH_FWD_MAT_HPP
#define STAN_MATH_FWD_MAT_HPP

#include <stan/math/fwd/core.hpp>
#include <stan/math/fwd/scal/meta/is_fvar.hpp>
#include <stan/math/fwd/scal/meta/partials_type.hpp>

#include <stan/math/fwd/mat/vectorize/apply_scalar_unary.hpp>
#include <stan/math/prim/mat.hpp>
#include <stan/math/fwd/arr.hpp>

#include <stan/math/fwd/mat/fun/Eigen_NumTraits.hpp>
#include <stan/math/fwd/mat/fun/columns_dot_product.hpp>
#include <stan/math/fwd/mat/fun/columns_dot_self.hpp>
#include <stan/math/fwd/mat/fun/crossprod.hpp>
#include <stan/math/fwd/mat/fun/determinant.hpp>
#include <stan/math/fwd/mat/fun/divide.hpp>
#include <stan/math/fwd/mat/fun/dot_product.hpp>
#include <stan/math/fwd/mat/fun/dot_self.hpp>
#include <stan/math/fwd/mat/fun/inverse.hpp>
#include <stan/math/fwd/mat/fun/log_determinant.hpp>
#include <stan/math/fwd/mat/fun/log_softmax.hpp>
#include <stan/math/fwd/mat/fun/log_sum_exp.hpp>
#include <stan/math/fwd/mat/fun/mdivide_left.hpp>
#include <stan/math/fwd/mat/fun/mdivide_left_ldlt.hpp>
#include <stan/math/fwd/mat/fun/mdivide_left_tri_low.hpp>
#include <stan/math/fwd/mat/fun/mdivide_right.hpp>
#include <stan/math/fwd/mat/fun/mdivide_right_tri_low.hpp>
#include <stan/math/fwd/mat/fun/multiply.hpp>
#include <stan/math/fwd/mat/fun/multiply_lower_tri_self_transpose.hpp>
#include <stan/math/fwd/mat/fun/qr_Q.hpp>
#include <stan/math/fwd/mat/fun/qr_R.hpp>
#include <stan/math/fwd/mat/fun/quad_form_sym.hpp>
#include <stan/math/fwd/mat/fun/rows_dot_product.hpp>
#include <stan/math/fwd/mat/fun/rows_dot_self.hpp>
#include <stan/math/fwd/mat/fun/softmax.hpp>
#include <stan/math/fwd/mat/fun/sort_asc.hpp>
#include <stan/math/fwd/mat/fun/sort_desc.hpp>
#include <stan/math/fwd/mat/fun/squared_distance.hpp>
#include <stan/math/fwd/mat/fun/sum.hpp>
#include <stan/math/fwd/mat/fun/tcrossprod.hpp>
#include <stan/math/fwd/mat/fun/to_fvar.hpp>
#include <stan/math/fwd/mat/fun/trace_gen_quad_form.hpp>
#include <stan/math/fwd/mat/fun/trace_quad_form.hpp>
#include <stan/math/fwd/mat/fun/typedefs.hpp>
#include <stan/math/fwd/mat/fun/unit_vector_constrain.hpp>

#include <stan/math/fwd/mat/functor/gradient.hpp>
#include <stan/math/fwd/mat/functor/jacobian.hpp>

#endif
